@@ -10,7 +10,6 @@
     wb_diff_frame.py
 
 '''
-import threading
 import wx
 import wx.stc
 
@@ -380,7 +379,6 @@ class DiffBodyText(wx.stc.StyledTextCtrl):
 
         wx.EVT_MOUSEWHEEL( self, self.OnMouseWheel )
         wx.EVT_SCROLLWIN( self, self.OnNeedToSyncScroll )
-        wx.stc.EVT_STC_UPDATEUI( self, -1, self.OnNeedToSyncScroll )
         WB_EVT_SYNC_SCROLL( self, -1, self.OnSyncScroll )
         DiffBodyText.body_count += 1
         self.body_count = DiffBodyText.body_count
